@@ -35,13 +35,13 @@ class Depends(Dependency):
         return self.call()
 
 
-class Publisher(Dependency):
+class GetPublisher(Dependency):
 
     def resolve(self, ctx: Context):
         return ctx.worker.get_publisher()
 
 
-class Payload(Dependency):
+class GetPayload(Dependency):
     def __init__(self, schema: Any):
         self.schema = schema
 
@@ -51,7 +51,7 @@ class Payload(Dependency):
         return obj
 
 
-class Task(Dependency):
+class GetTask(Dependency):
 
     def resolve(self, ctx: Context):
         return ctx.task
