@@ -20,7 +20,7 @@ from functools import partial
 from humanize import naturalsize, naturaldelta
 from pydantic import BaseModel
 from time import time
-from typing import Mapping, MutableMapping, Iterable, Dict, Type, Optional
+from typing import Mapping, MutableMapping, Iterable, Dict, Type, Optional, Literal
 
 from patchwork.core import AsyncPublisher, AsyncSubscriber, Component
 from patchwork.core.client.local import AsyncLocalPublisher, AsyncLocalSubscriber
@@ -45,26 +45,7 @@ class WorkerSettings(BaseModel):
     debug: bool = False
     enabled: bool = True
 
-    logging: LoggingConfig = LoggingConfig({
-        'version': 1,
-        'disable_existing_loggers': False,
-        'root': {
-            'level': 'DEBUG',
-            'handlers': ['console']
-        },
-        'formatters': {
-            'simple': {
-                'format': '%(relativeCreated)d\t%(name)s\t%(levelname)s\t%(message)s'
-            },
-        },
-        'handlers': {
-            'console': {
-                'level': 'DEBUG',
-                'class': 'logging.StreamHandler',
-                'formatter': 'simple'
-            }
-        }
-    })
+    logging: LoggingConfig = None
 
     # executor unit
     executor: ComponentConfig[Type[BaseExecutor]] = ComponentConfig(BaseExecutor)
@@ -128,6 +109,30 @@ class PatchworkWorker(Module):
     def modules(self):
         return {k: v.instantiate(parent=self) for k, v in self.settings.modules.items()}
 
+    @property
+    def debug(self):
+        return self.settings.debug
+
+    def middleware(self, flow: Literal['task'] = 'task'):
+
+        if flow == 'task':
+            def wrapper(fn):
+                assert asyncio.iscoroutinefunction(fn)
+                self.executor.add_middleware(fn)
+                return fn
+        else:
+            raise NotImplementedError()
+
+        return wrapper
+
+    def exception_handler(self, exception_class: type):
+        def wrapper(fn):
+            assert asyncio.iscoroutinefunction(fn)
+            self.executor.add_exception_handler(exception_class, fn)
+            return fn
+
+        return wrapper
+
     def _load_settings(self, settings: Mapping = None):
         """
         Load settings from worker settings JSON file and then updates values
@@ -201,7 +206,7 @@ class PatchworkWorker(Module):
             self.terminate_worker()
             return
 
-        self.logger.debug("Node is up and running")
+        self.logger.info("Node is up and running")
 
         # noinspection PyBroadException
         try:
