@@ -2,15 +2,23 @@
 import asyncio
 
 import pytest as pytest
-
 from patchwork.core import Task
+
 from patchwork.node import PatchworkWorker
 from patchwork.node.core.router import TaskRouter
 
 
 @pytest.fixture
 async def worker():
-    worker = PatchworkWorker()
+    worker = PatchworkWorker(settings={
+        'subscriber': {
+            'engine': 'patchwork.core.client.local:AsyncLocalSubscriber',
+            'queue_names': ['test'],
+        },
+        'publisher': {
+            'engine': 'patchwork.core.client.local:AsyncLocalPublisher',
+        }
+    })
     await worker.run()
     yield worker
 
@@ -29,9 +37,14 @@ async def test_simple_use(worker):
         caught_tasks.append(task)
 
     worker.include_router(router)
-    await worker.get_publisher().send_task(Task(task_type='test-msg'))
+
+    async def send():
+        task = Task(task_type='test-msg')
+        task.meta.queue_name = 'test'
+        await worker.get_publisher().send_task(task)
+
+    asyncio.create_task(send())
 
     # wait until executor processing unit becomes busy which means given message has been consumed
     await asyncio.wait_for(worker.executor.unit.busy.wait(), timeout=1)
-
     assert len(caught_tasks) == 1
